#
# spec file for package python-QtPy
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-QtPy
Version:        1.9.0
Release:        bp155.2.12
Summary:        Abstraction layer on top of Qt bindings
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/spyder-ide/qtpy
Source:         https://files.pythonhosted.org/packages/source/Q/QtPy/QtPy-%{version}.tar.gz
Patch0:         0001-Add-QtDatavisualization-alias-to-QtDataVisualization.patch
BuildRequires:  %{python_module qt3d-qt5}
BuildRequires:  %{python_module qt5}
BuildRequires:  %{python_module qtdatavis3d-qt5}
BuildRequires:  %{python_module qtwebengine-qt5}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Recommends:     python-qt3d-qt5
Recommends:     python-qt5
Recommends:     python-qtdatavis3d-qt5
Recommends:     python-qtwebengine-qt5
Suggests:       python-pyside2
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  xvfb-run
# /SECTION
%python_subpackages

%description
QtPy (pronounced 'cutie pie') is a small abstraction layer that lets you
write applications using a single api call to either PyQt or PySide.

It provides support for PyQt5, PyQt4 and PySide using the PyQt5 layout (where
the QtGui module has been split into QtGui and QtWidgets).

Basically, you write your code as if you were using PyQt5 but import qt from
`qtpy` instead of `PyQt5`.

%prep
%setup -q -n QtPy-%{version}
sed -i 's/\r$//' LICENSE.txt
rm qtpy/tests/runtests.py
# Submitted to upstream at gh#spyder-ide/qtpy#228
mv qtpy/QtDatavisualization.py qtpy/QtDataVisualization.py
%patch0 -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export QT_HASH_SEED=0
export PYTHONDONTWRITEBYTECODE=1
mkdir empty
pushd empty
%{python_expand # pytest-xvfb unfortunately fails here
export PYTHONPATH=%{buildroot}%{$python_sitelib}
xvfb-run --server-args="-screen 0 1920x1080x24" pytest-%{$python_bin_suffix} -v ../qtpy/tests/
}
popd

%files %{python_files}
%doc AUTHORS.md CHANGELOG.md README.md
%license LICENSE.txt
%{python_sitelib}/qtpy
%{python_sitelib}/QtPy-%{version}-py*.egg-info

%changelog
* Thu Jan 21 2021 Antonio Larrosa <alarrosa@suse.com>
- Add patch so the renaming of QtDataVisualization doesn't cause
  a problem on applications using the old name
  (gh#spyder-ide/qtpy#228):
  * 0001-Add-QtDatavisualization-alias-to-QtDataVisualization.patch
* Thu Jan 14 2021 Antonio Larrosa <alarrosa@suse.com>
- Add also BuildRequires for qt3d-qt5 and qtdatavis3d-qt5 so
  those tests are not skipped.
- qtcharts-qt5 is not added because the python-qt5 package is
  always pulled in automatically and QtPy uses it by default
  while QtCharts is only available with PySide2.
- Replace the Requires with Recommends since not even PyQt is
  really required (PySide2 can also be used with QtPy, and is now
  added as a Suggested package).
- Rename QtDatavisualization.py to QtDataVisualization.py
  (uppercase v) to fix the test which was skipped because the
  imported module didn't exist and to keep the name consistent
  with both PyQt and PySide2 (gh#spyder-ide/qtpy#228)
* Wed Jan 13 2021 Antonio Larrosa <alarrosa@suse.com>
- BuildRequires (and Require) the webengine bindings so it uses
  them (which is the default) instead of using qtwebkit (which
  was used only as a fallback).
* Fri Aug 28 2020 Benjamin Greiner <code@bnavigator.de>
- SIP is only used for PyQt4 which we don't use
* Mon Jul 29 2019 pgajdos@suse.com
- version update to 1.9.0
  * Add the FORCE_QT_API environment variable to keep using the Qt
    bindings selected with the QT_API variable and avoid switching
    to the currently imported bindings. This allows to have
    applications that import PySide and PyQt bindings at the same
    time (which is possible if both bindings are compiled for the
    same Qt version).
  * Errors in the Qt3D modules with PySide2 5.12.4+ and Python 2
  * Binding Selection Logic
  * PR: Don't load Qt3D modules for buggy versions of PySide2
  * PR: Add FORCE_QT_API environment variable
* Mon Jul 22 2019 Todd R <toddrme2178@gmail.com>
- Update to 1.8.0
  * Add support for several Qt 3D modules.
* Thu May 23 2019 pgajdos@suse.com
- version update to 1.7.1
  * Skip testing PyQt4 and PySide in Python 3.5
  * Trivial maintenance tweaks
  * Avoid deprecated "from collections import MutableMapping"
* Tue Mar 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.7.0:
  * Add support for QtCharts.
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.6.0:
  * Add support for QtQuickWidgets
  * Issue 178 - Error when import QtCore.version in PySide2
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Nov  8 2018 Todd R <toddrme2178@gmail.com>
- Update to Version 1.5.2
  * Fix tests
  * Add support for PySide2.QtOpenGL
- Update to Version 1.5.1
  * Make PythonQtError inherit from RuntimeError to be easily
    catchable
- Update to Version 1.5
  + New features
  * Add support for QtLocation, QtMultimediaWidgets, QtQml,
    QtQuick, QtWebChannel, QtWebSockets and QtXmlPatterns.
  * Raise an error when trying to use the wrong combination of
    macOS and Qt versions.
  + Issues Closed
  * Issue 155 - Add warnings for Qt 5.9 in macOS 10.9 and
    Qt 5.11 and macOS 10.11 (PR 168)
  * Issue 153 - Shim PyQt5 ToPyDateTime for compatibility with
    PySide2 (PR 169)
  * Issue 123 - Wrap QWebChannel module (PR 157)
  + Pull Requests Merged
  * PR 169 - Shim PyQt5 QDateTime.toPyDateTime to
    QDateTime.toPython for compatibility with PySide2 (153)
  * PR 168 - Raise error when trying to use the wrong
    combination of macOS and Qt versions (155)
  * PR 167 - Migrate to CircleCI 2.0
  * PR 163 - Add QtLocation
  * PR 162 - Update readme to remove funding appeal, harmonize
    with other readmes and minor fixes
  * PR 161 - Fix pyside2 wheels install
  * PR 157 - Add more Qt modules (123)
* Thu May 31 2018 toddrme2178@gmail.com
- Update to version 1.4.2
  + Issues Closed
  * Issue 150 - PySide2-5.11 alpha2 compatibility (PR 151)
  * Issue 144 - ValueError: API 'QString' has already been set to version 1 at line 141 in init.py file. (PR 152)
  + Pull Requests Merged
  * PR 152 - PR: Catch ValueError when trying to set sip API (144)
  * PR 151 - PR: Add a preventive change for PySide-5.11a2 (150)
  * PR 149 - PR: Use Qt official wheels to run tests for PySide2
  * PR 148 - PR: Remove internal conda recipe
* Sat Apr 28 2018 toddrme2178@gmail.com
- Update to Version 1.4.1
  + New features
  * Show a warning when QT_API is changed automatically by qtpy.
  + Issues Closed
  * Raise a warning if QT_API value is changed automatically
  * On OSX qtpy applications are forcing discrete graphics
  + Pull Requests Merged
  * Add better compatibility with PySide2
  * Add a warning if API is changed automatically
  * Avoid using PyQt5.Qt, which imports unneeded stuff and forces
    discrete GPU on OSX
- Update to Version 1.4 (2018-03-11)
  + New features
  * Add support for QtHelp
  * Add support for QtSql
  * Use already imported bindings
  + Issues Closed
  * If one binding has already been imported,
    then qtpy should just use it
  * Add Wrapper for QtSql
  * Methods missing from QStandardPaths when QT_API=pyqt4
  * Add Wrapper for QtHelp
  + Pull Requests Merged
  * Pin PyQt5 to 5.9.2 in CircleCI because 5.10 is generating segfaults
  * If a Qt binding is already imported, then use it.
  * Add QtSql wrapper (incl. test)
  * Changes to QDesktop split
  * Add QtHelp Wrapper
* Mon Aug 28 2017 toddrme2178@gmail.com
- Update to Version 1.3.1
  + Bugs fixed
  * Spurious cache files in PyPI tarball
  * Importing qtpy should not raise exceptions
  * No cache files included in the release tarball
  * Remove Quantified Code badge because the service doesn't exist anymore
  * Warn if QHeaderView deprecated methods are used
- Update to Version 1.3
  + New features
  * Add support for PySide2
  * Add support for QtMultimedia
  * Add support for PyQt 4.6
  + Bugs fixed
  * Typo in readme title
  * Update Readme for 1.3 release
  * Add tests for untested modules
  * Missing: QtOpenGL Module
  * QDesktopServices split into QDesktopServices and QStandardPaths
  * qInstallMessageHandler <-> qInstallMsgHandler
  * Feature Request: PySide2 support
  * Fix typo in Readme.
  * Add compatibility for the rename of qInstallMsgHandler to qInstallMessageHandler
  * Update Readme to reflect that we actually use the PySide2 layout
  * Update Readme to mention that we now support PySide2.
  * Add tests for Qtdesigner, QtNetwork, QtPrintSupport, QtSvg and QtTest.
  * Follow QStandardPaths location in Qt5 for PyQt4/PySide
  * Add a coveragerc file
  * Add support for PyQt 4.6
  * Add a new QtOpenGL module
  * Add PySide2 support
* Fri Apr 28 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Feb 16 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.2.1
  - Bugs fixed:
    Pull requests
    + PR 98 - PR: Don't use Travis to test macOS because it slows
    down the entire spyder-ide organization
    + PR 97 - PR: Update Appveyor badge in Readme because of moving
    to an org account
    + PR 94 - PR: Include test suite in sdist
- Version 1.2
  - New features:
    + Add support for QtMultimedia
    + Use relative imports so its vendored more easily
  - Bugs fixed:
    Issues
    + Issue 83 - Include core doc files in PyPi releases
    + Issue 78 - Request for a new bugfix release
    + Issue 75 - Missing copyright headers
    + Issue 67 - uic.loadUiType is missing
    + Issue 64 - QHeaderView.setSectionResizeMode
    + Issue 49 - QtMultimedia support
    Pull requests
    + PR 93 - Restore uic full namespace for PyQt5 and PyQt4
    + PR 92 - Add missing copyright header in _patch/qheaderview.py
    + PR 91 - Use star imports in QtSvg again instead of direct
    ones (reverts PR #55)
    + PR 88 - PR: Add manifest
    + PR 74 - Move QStringListModel to QtCore
    + PR 71 - PR: Use relative imports so its vendored more easily
    + PR 65 - Introduce renamed methods of QHeaderView in PyQt4 and
    PySide
    + PR 59 - Don't install qtpy as a conda package in CircleCI
    + PR 58 - Remove reference to how qtpy is pronounced in README
    + PR 55 - PR: Add explicit imports to QtSvg module
    + PR 50 - Add support for QtMultimedia
- Removed source file LICENSE.txt, fixed upstream.
* Thu Oct 13 2016 toddrme2178@gmail.com
- Initial version
